@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.107_03';
+our $VERSION = '0.108_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sat Oct  6 17:58:12 2018 GMT
+# on Wed Oct 10 14:19:06 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1769,9 +1769,9 @@ __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
 __PACKAGE__->status( add => 25528, iridium => 'D', 'Iridium 86', 'Decayed 2018-10-05' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
 __PACKAGE__->status( add => 25530, iridium => '-', 'Iridium 84', 'Tumbling' );
-__PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
+__PACKAGE__->status( add => 25531, iridium => 'S', 'Iridium 83', '' );
 __PACKAGE__->status( add => 25577, iridium => 'S', 'Iridium 20', '' );
-__PACKAGE__->status( add => 25578, iridium => 'S', 'Iridium 11', '' );
+__PACKAGE__->status( add => 25578, iridium => '-', 'Iridium 11', 'Tumbling' );
 __PACKAGE__->status( add => 25777, iridium => '+', 'Iridium 14', '' );
 __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-05-24' );
 __PACKAGE__->status( add => 27372, iridium => '+', 'Iridium 91', '' );
@@ -1783,9 +1783,9 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 10
+# Operational [+]: 9
 #       Spare [S]: 10
-#    Tumbling [-]: 37
+#    Tumbling [-]: 38
 #     Decayed [D]: 40
 
 1;
